pub struct GenericSolver;Expand description
A utility for bypassing automated bot detections and CAPTCHAs.
GenericSolver contains various methods to solve or evade generic security puzzles,
such as Cloudflare Turnstile or similar challenges.
Implementations
Sourceimpl GenericSolver
impl GenericSolver